﻿using System;

namespace HeuristicLab.Problems.ProgramSynthesis {
  using HeuristicLab.Core;

  public static class RandomExtensions {
    /// <summary>
    /// Generates a random biased towards min
    /// <see href="https://gamedev.stackexchange.com/questions/116832/random-number-in-a-range-biased-toward-the-low-end-of-the-range">Source</see>
    /// </summary>
    /// <param name="min">Minimum random int</param>
    /// <param name="max">Maximum random int</param>
    /// <param name="biasLevel">The bigger this values is, the bigger is the probability that min will be generated</param>
    /// <param name="random">Random number generater</param>
    /// <returns></returns>
    public static int NextBiased(this IRandom random, int min, int max, double biasLevel) {
      return (int)(min + (max - min) * Math.Pow(random.NextDouble(), biasLevel));
    }
  }
}
